Struct AtaPassThruProtocol
Source #[repr(C)]
pub struct AtaPassThruProtocol {
pub mode: *const AtaPassThruMode,
pub pass_thru: unsafe extern "efiapi" fn(this: *mut Self, port: u16, port_multiplier_port: u16, packet: *mut AtaPassThruCommandPacket, event: Event) -> Status,
pub get_next_port: unsafe extern "efiapi" fn(this: *const Self, port: *mut u16) -> Status,
pub get_next_device: unsafe extern "efiapi" fn(this: *const Self, port: u16, port_multiplier_port: *mut u16) -> Status,
pub build_device_path: unsafe extern "efiapi" fn(this: *const Self, port: u16, port_multiplier_port: u16, device_path: *mut *const DevicePathProtocol) -> Status,
pub get_device: unsafe extern "efiapi" fn(this: *const Self, device_path: *const DevicePathProtocol, port: *mut u16, port_multiplier_port: *mut u16) -> Status,
pub reset_port: unsafe extern "efiapi" fn(this: *mut Self, port: u16) -> Status,
pub reset_device: unsafe extern "efiapi" fn(this: *mut Self, port: u16, port_multiplier_port: u16) -> Status,
}
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.